@@ -254,12 +254,16 @@ pub mod remote_control_command_request;
 pub use self::remote_control_command_request::RemoteControlCommandRequest;
 pub mod software_enum;
 pub use self::software_enum::SoftwareEnum;
+pub mod status_enum;
+pub use self::status_enum::StatusEnum;
 pub mod system_task;
 pub use self::system_task::SystemTask;
 pub mod system_task_request;
 pub use self::system_task_request::SystemTaskRequest;
 pub mod system_task_status;
 pub use self::system_task_status::SystemTaskStatus;
+pub mod system_task_status_request;
+pub use self::system_task_status_request::SystemTaskStatusRequest;
 pub mod system_task_type;
 pub use self::system_task_type::SystemTaskType;
 pub mod telemetry_event;
